All Classes and Interfaces
Class
Description
Base class for version implementations.
Represents an artifact version adhering to the Calendar Versioning
specification.
Parses a calendar version according to the specified format.
Represents a single component in a calendar version.
Indicates the category for a calendar version component.
Translates high level NPM dependency constraints to the equivalent low level constraints.
Represents the version of a Debian package.
Represents the version scheme used by a Debian package.
Represents the version of an artifact in the RubyGems ecosystem.
Represents the version scheme used by the RubyGems packaging system.
Represents the version of an artifact in the Gradle ecosystem.
Represents the version scheme used by the Gradle build tool.
Represents a version of the Java language.
Represents the version scheme used by the Java language.
Represents the version of an artifact in the Maven ecosystem.
Represents the version scheme used by the Maven build tool.
Represents the version scheme used by the NPM ecosystem.
Represents a Python Packaging Authority version specifier.
Represents the constructor of a specifier class.
Represents a set of Python Packaging Authority version specifier.
Represents a version conforming to the Python Packaging Authority (PyPA)
Version Specifiers
specification.
Normalized pre-release phase identifier.
Represents the
version scheme
specified by the Python Packaging Authority (PyPA) for Python software packages.
Represents an artifact version adhering to the Semantic Versioning 2.0
specification.
Indicates the separator used between two calendar version components.
Represents an artifact version.
Represents zero (empty constraint) or more version ranges.
Indicates an error was encountered while parsing or working with a version or version constraint.
Represents a single range of versions.